@@ -1,11 +1,12 @@
 import networkx as nx
 # import pygraphviz
 import ast
-from astgraph import AstVisitor
+from GeneratorOfFibAST.astgraph import AstVisitor
 import os
 
 def main():
-    with open('GeneratorOfFibAST/fib.py', 'r') as sourse:
+    with open('/Library/anaconda3/lib/python3.9/site-packages/GeneratorOfFibAST/fib.py', 'r') as sourse:
+        # i have no idea why i need full path...
         tree = ast.parse(sourse.read())
 
     # делаем гарф
